==> Amino.py-3.0.2.tar.gz: Amino.py-3.0.2/README.md <==

[//]: # (**README Improved By ODYSS3EUS**)
[//]: # (Never Underestimate Presentation)
[//]: # (Mae: Professionals have standards)
[//]: # (Koi: Indeed...)
<h1 align="center">
  <br>
  <a href="https://github.com/Slimakoi/Amino.py"><img src="https://cdn.discordapp.com/icons/715911730550800514/8b577d0f9d38614422601a71e91b866d.png?size=512" alt="Amino.py" width="200"></a>
  <br>
  Amino.py
  <br>
</h1>

<p align="center">
  <a href="https://discord.gg/68wchgsKdX"><img src="https://bit.ly/32neyjM"></a>
  <p align="center"> If you have any questions, join us on Discord! </p>
</p>

#### What is this?
Amino.py is a Python API for communicating with Amino's Servers while pretending that you're an App User. This is mostly accomplished by spoofing Device Configuration Headers, while objectifying and organizing Amino Response Data, so that actually doing anything is easier.


#### How do I use this?
Python 3.8 is the recommended version for Amino.py, only supports Python 3.x.

To install Amino.py, run `python3 -m pip install amino.py`.
- **NOTE:** MAKE SURE YOU TYPE `amino.py` **NOT** `amino` AS IT WILL INSTALL THE **WRONG** PACKAGE!


### API Reference
[Read the Docs Link](https://aminopy.readthedocs.io/en/latest/)

#### Alternative Installation (Not recommended)
0. Make sure pip is installed and added to PATH, see: [How to setup pip](https://nitratine.net/blog/post/how-to-setup-pythons-pip/)
1. Alternatively download the API from GitHub [here](https://github.com/Slimakoi/Amino.py/archive/refs/heads/master.zip)
2. Extract the .zip file either with [WinRAR](https://www.win-rar.com/download.html?&L=0) or [7-Zip](https://www.7-zip.org/download.html)
3. Open the extracted folder in an IDE of your choice, and navigate to the folder named `Amino.py-master`
4. Select the Python Interpreter
5. Make a new `*.py` file and start coding

[//]: # (*Verbose Instructions For Those Who Want To Start Programming But Don't Know How.)
[//]: # (Mae: Who knows their stuff will do how to do this and who doesn't won't need this. Consider replacing this section entirely.)

[//]: # (PS: This additionally adds more confusion for users, which already created reports of circular imports and more headaches. Pip installs are easier to understand for end users. Pip simplifies everything when dealing with dependencies, updates, installs and removals. Windows Python's default install installs Pip, MOST [not looking at you arch] Distros package python with Pip alongside Python. Who "starting programming" will ever use this?)

==> Amino.py-3.0.6.tar.gz: Amino.py-3.0.6/README.md <==

[//]: # (**README Improved By ODYSS3EUS**)
[//]: # (Never Underestimate Presentation)
[//]: # (Mae: Professionals have standards)
[//]: # (Koi: Indeed...)
<h1 align="center">
  <br>
  <a href="https://github.com/Slimakoi/Amino.py"><img src="https://cdn.discordapp.com/icons/715911730550800514/8b577d0f9d38614422601a71e91b866d.png?size=512" alt="Amino.py" width="200"></a>
  <br>
  Amino.py
  <br>
</h1>

<p align="center">
  <a href="https://discord.gg/68wchgsKdX"><img src="https://bit.ly/32neyjM"></a>
  <p align="center"> If you have any questions, join us on Discord! </p>
</p>

#### What is this?
Amino.py is a Python API for communicating with Amino's Servers while pretending that you're an App User. This is mostly accomplished by spoofing Device Configuration Headers, while objectifying and organizing Amino Response Data, so that actually doing anything is easier.


#### How do I use this?
Python 3.8 is the recommended version for Amino.py, only supports Python 3.x.

To install Amino.py, run `python3 -m pip install amino.py` or `pip install amino.py`.
- **NOTE:** MAKE SURE YOU TYPE `amino.py` **NOT** `amino` AS IT WILL INSTALL THE **WRONG** PACKAGE!


### API Reference
[Read the Docs Link](https://aminopy.readthedocs.io/en/latest/)

#### Alternative Installation (Not recommended)
0. Make sure pip is installed and added to PATH, see: [How to setup pip](https://nitratine.net/blog/post/how-to-setup-pythons-pip/)
1. Alternatively download the API from GitHub [here](https://github.com/Slimakoi/Amino.py/archive/refs/heads/master.zip)
2. Extract the .zip file either with [WinRAR](https://www.win-rar.com/download.html?&L=0) or [7-Zip](https://www.7-zip.org/download.html)
3. Open the extracted folder in an IDE of your choice, and navigate to the folder named `Amino.py-master`
4. Select the Python Interpreter
5. Make a new `*.py` file and start coding

[//]: # (*Verbose Instructions For Those Who Want To Start Programming But Don't Know How.)
[//]: # (Mae: Who knows their stuff will do how to do this and who doesn't won't need this. Consider replacing this section entirely.)

[//]: # (PS: This additionally adds more confusion for users, which already created reports of circular imports and more headaches. Pip installs are easier to understand for end users. Pip simplifies everything when dealing with dependencies, updates, installs and removals. Windows Python's default install installs Pip, MOST [not looking at you arch] Distros package python with Pip alongside Python. Who "starting programming" will ever use this?)
